@@ -17,7 +17,7 @@ class ctc_adult_individual_maximum(Variable):
     )
 
     def formula_2018(person, period, parameters):
-        ctc = parameters(period).irs.credits.ctc
+        ctc = parameters(period).gov.irs.credits.ctc
         is_dependent = person("is_tax_unit_dependent", period)
         is_child = person("is_ctc_qualifying_child", period)
         is_adult_dependent = ~is_child & is_dependent
